#ifndef ILOGWRITER_HPP
#define ILOGWRITER_HPP

#include "EntryType.hpp"
#include "ExtendedLog_global.h"

#include <QString>

namespace ExtendedLog
{
	/**
	 * @brief An abstract log writer
	 */
	class EXTENDEDLOG_EXPORT LogWriter
	{
		public:
			/**
			 * @brief Delete this log writer object
			 */
			virtual ~LogWriter() {}

			/**
			 * @brief Write an LogEntry to the log file
			 * @param type The type of the entry
			 * @param message The message of the entry
			 *
			 * This method writes an log-entry, specified by its type and message, to the log-file.
			 * The concrete implementation of this method depends on the "real" log writer that is used.
			 */
			virtual void writeEntry(EntryType type, QString message) = 0;

			/**
			 * @brief Close this log writer
			 */
			virtual void close() = 0;
	};
	
} // namespace ExtendedLog

#endif // ILOGWRITER_HPP
