#ifndef MULTIPLELOGWRITER_HPP
#define MULTIPLELOGWRITER_HPP

#include "EntryType.hpp"
#include "ExtendedLog_global.h"
#include "LogWriter.hpp"

#include <QString>
#include <QVector>

namespace ExtendedLog
{
	/**
	 * @brief Writing multiple logs at once
	 *
	 * This class provides helper function to write multiple log-files at the same time.
	 * Therefore its using LogWriter objects defined by the user.
	 */
	class EXTENDEDLOG_EXPORT MultipleLogWriter : public LogWriter
	{
		public:
			/**
			 * @brief Create a new instance of this class
			 */
			MultipleLogWriter();

			/**
			 * @brief Add an LogWriter to the list of used log-writers
			 * @param The log-writer to add
			 */
			void addWriter(LogWriter &logWriter);

			/**
			 * @brief Removes the first occourence of \p logWriter from the list of writers
			 * @param logWriter The LogWriter to remove
			 * @return <tt>true</tt> if the removing was successfull, <tt>false</tt> otherwise
			 */
			bool removeWriter(LogWriter &logWriter);

			/**
			 * @brief Write an LogEntry to the log file
			 * @param type The type of the entry
			 * @param message The message of the entry
			 *
			 * This method writes an log-entry, specified by its type and message, to the log-file
			 * by invoking all registered log-writers.
			 */
			void writeEntry(EntryType type, QString message);

			/**
			 * @brief Close this log-writer
			 *
			 * This closes all registered log-writers
			 */
			void close();
	
		private:
			QVector<LogWriter*> logWriters;
	};
} // namespace ExtendedLog

#endif // MULTIPLELOGWRITER_HPP
