#ifndef XMLLOGREADER_HPP
#define XMLLOGREADER_HPP

#include "ExtendedLog_global.h"
#include "LogReader.hpp"

#include <QFile>
#include <QString>
#include <QXmlStreamReader>

namespace ExtendedLog
{
	/**
	 * @brief Class for reading XML-based log-files
	 */
	class EXTENDEDLOG_EXPORT XmlLogReader : public LogReader
	{
		public:
			/**
			 * @brief Create a new XML-based log-reader
			 * @param filename The file to read from
			 */
			XmlLogReader(QString filename);
	
		private:
			/**
			 * @brief The log-file as file representation
			 */
			QFile inputFile;

			/**
			 * @brief The XML-reader
			 */
			QXmlStreamReader logReader;

			/**
			 * @brief Read all entries from file
			 */
			void readAllEntries() override;

			/**
			 * @brief Read the next entry from file
			 *
			 * This is a helper method for readAllEntries.
			 * If the log-file is not in the correct format the assertion in this method fails.
			 */
			void readNextEntry();
	};
} // namespace ExtendedLog
#endif // XMLLOGREADER_HPP
